Documentation
¶
Index ¶
Constants ¶
const ( MetadataEncodingEncrypted = "binary/encrypted" MetadataEncryptionKeyID = "encryption-key-id" MetadataEncryptionKeyVersion = "encryption-key-version" )
Variables ¶
var PropagateKey = contextKey{}
PropagateKey is the key used to store the value in the Context object
Functions ¶
func NewContextPropagator ¶
func NewContextPropagator() workflow.ContextPropagator
NewContextPropagator returns a context propagator that propagates a set of string key-value pairs across a workflow
Types ¶
type CryptContext ¶
type CryptContext struct {
KeyID string `json:"keyId"`
}
CryptConfig is a struct holding values
type DataConverter ¶
type DataConverter struct {
converter.DataConverter
// contains filtered or unexported fields
}
func NewEncryptionDataConverter ¶
func NewEncryptionDataConverter(client *vault.Client, dataConverter converter.DataConverter, options DataConverterOptions) *DataConverter
NewEncryptionDataConverter creates a new instance of EncryptionDataConverter wrapping a DataConverter
func (*DataConverter) WithContext ¶
func (dc *DataConverter) WithContext(ctx context.Context, client *vault.Client) converter.DataConverter
TODO: Implement workflow.ContextAware in EncodingDataConverter Note that you only need to implement this function if you need to vary the encryption KeyID per workflow.
type DataConverterOptions ¶
Click to show internal directories.
Click to hide internal directories.